@@ -38,7 +38,8 @@ get_summary <- function(split = c("overall", "province", "region")) {
   ) %>%
     dplyr::mutate(
       dplyr::across(tidyselect::matches("^change|total"), as.integer),
-      dplyr::across(tidyselect::matches("date"), as.Date),
-      last_updated = as.POSIXct(.data$last_updated)
+      dplyr::across(tidyselect::matches("latest_date"), as.Date),
+      last_updated = as.POSIXct(.data$last_updated,
+                                tz = "America/Regina")
     )
 }
